# Generated by roxygen2: do not edit by hand

export(alfalfa_soil)
export(apple_canker)
export(apple_uniformity)
export(arabica_soil)
export(arabica_temp)
export(arabica_terrain)
export(arabica_water)
export(avocado_us_sale)
export(bamboo_growth)
export(biological_control)
export(bird_grazing)
export(black_duck_survival)
export(blackgrass_herbicide)
export(broiler_growth)
export(budworm_pyrethroid)
export(carrot_fly_infestation)
export(carrot_insecticide)
export(cattle_butterfat)
export(cauliflower_growth)
export(coffee_composition)
export(coffee_production)
export(cork_tree_direction)
export(corn_hybrid_density)
export(cotton_pesticide)
export(cowpea_maize_yield)
export(cows_insemination)
export(earthworm_crop_soils)
export(earthworm_population)
export(eelworm_fumigation)
export(egg_weight_daily)
export(eucalyptus_progenies)
export(fish_feeding)
export(fungicide_latin_square)
export(grape_uniformity)
export(guinea_pig_sleep)
export(hawaii_plant_size)
export(hawaii_tree_growth)
export(idn_rice_farms)
export(kiwi_crop_design)
export(ladybird_fungus)
export(lamb_births)
export(nitrofen_toxicity)
export(orange_rootstocks)
export(peach_uniformity)
export(pig_weight_gain)
export(plant_growth_regulator)
export(pollen_removal)
export(potato_scab_sulfur)
export(rabbit_body_mass)
export(red_wine_quality)
export(rice_wheat_production)
export(river_deforestation)
export(robusta_soil)
export(robusta_temp)
export(robusta_terrain)
export(robusta_water)
export(seed_germination)
export(soil_munsell_colors)
export(soil_munsell_minerals)
export(soybean_cultivars)
export(strawberry_cross_disease)
export(strawberry_yield)
export(timber_genetics)
export(tomato_insecticides)
export(tomato_uniformity)
export(toxin_lethal_dose)
export(turnip_density)
export(us_state_soils)
export(view_datasets_agridatasets)
export(wheat_bunt)
export(wheat_splitsplit)
export(willow_cutting_yield)
