# agridatasets - A Comprehensive Collection of Agricultural and Agronomic Datasets
# Version 0.1.1
# Copyright (C) 2026 Renzo Caceres Rossi
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

#' agridatasets: A Comprehensive Collection of Agricultural and Agronomic Datasets
#'
#' \if{html}{\figure{logo.png}{options: style='float: right' alt='logo' width='120'}}
#'
#' A Comprehensive Collection of Agricultural and Agronomic Datasets.
#'
#' @name agridatasets
#' @aliases agridatasets-package
#' @title agridatasets: A Comprehensive Collection of Agricultural and Agronomic Datasets
#' @description {
#' This package provides a diverse collection of datasets focused on agriculture, agronomy, animal science, and related fields. The package includes experimental, observational, and field-trial data on crops such as rice, wheat, corn, soybean, cotton, coffee, avocado, and orange, as well as forestry species including bamboo, eucalyptus, and timber.
#' }
#' @seealso {
#' Useful links:
#' \itemize{
#'   \item \url{https://github.com/lightbluetitan/agridatasets}
#' }
#' }
#' @author {
#' \strong{Maintainer}: Renzo Caceres Rossi \email{arenzocaceresrossi@gmail.com}
#' }
'_PACKAGE'
