# agridatasets - A Comprehensive Collection of Agricultural and Agronomic Datasets
# Version 0.1.1
# Copyright (C) 2026 Renzo Caceres Rossi
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

# cowpea_maize_yield

library(testthat)

# Test 1: Check that the object is a data.frame and has 6 columns
test_that("cowpea_maize_yield is a data.frame with 6 columns", {
  expect_s3_class(cowpea_maize_yield, "data.frame")
  expect_equal(ncol(cowpea_maize_yield), 6)
  expect_equal(length(cowpea_maize_yield), 6)
})

# Test 2: Check the number of rows
test_that("cowpea_maize_yield has 72 rows", {
  expect_equal(nrow(cowpea_maize_yield), 72)
})

# Test 3: Validate column names
test_that("cowpea_maize_yield has correct column names", {
  expect_named(
    cowpea_maize_yield,
    c("block", "nitro", "cowpea", "maize", "cyield", "myield")
  )
})

# Test 4: Check data types
test_that("cowpea_maize_yield has correct data types", {
  expect_s3_class(cowpea_maize_yield$block, "factor")
  expect_equal(nlevels(cowpea_maize_yield$block), 3)
  expect_s3_class(cowpea_maize_yield$nitro, "factor")
  expect_equal(nlevels(cowpea_maize_yield$nitro), 4)
  expect_s3_class(cowpea_maize_yield$cowpea, "factor")
  expect_equal(nlevels(cowpea_maize_yield$cowpea), 2)
  expect_s3_class(cowpea_maize_yield$maize, "factor")
  expect_equal(nlevels(cowpea_maize_yield$maize), 3)
  expect_type(cowpea_maize_yield$cyield, "integer")
  expect_type(cowpea_maize_yield$myield, "integer")
})
