# agridatasets - A Comprehensive Collection of Agricultural and Agronomic Datasets
# Version 0.1.1
# Copyright (C) 2026 Renzo Caceres Rossi
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

# fungicide_latin_square


library(testthat)

# Test 1: Check that the object is a data.frame and has 4 columns
test_that("fungicide_latin_square is a data.frame with 4 columns", {
  expect_s3_class(fungicide_latin_square, "data.frame")
  expect_equal(ncol(fungicide_latin_square), 4)
  expect_equal(length(fungicide_latin_square), 4)
})

# Test 2: Check the number of rows
test_that("fungicide_latin_square has 25 rows", {
  expect_equal(nrow(fungicide_latin_square), 25)
})

# Test 3: Validate column names
test_that("fungicide_latin_square has correct column names", {
  expect_named(
    fungicide_latin_square,
    c("trt", "yield", "row", "col")
  )
})

# Test 4: Check data types
test_that("fungicide_latin_square has correct data types", {
  expect_s3_class(fungicide_latin_square$trt, "factor")
  expect_equal(nlevels(fungicide_latin_square$trt), 5)
  expect_type(fungicide_latin_square$yield, "double")
  expect_type(fungicide_latin_square$row, "integer")
  expect_type(fungicide_latin_square$col, "integer")
})
