# agridatasets - A Comprehensive Collection of Agricultural and Agronomic Datasets
# Version 0.1.1
# Copyright (C) 2026 Renzo Caceres Rossi
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

# carrot_fly_infestation

library(testthat)

# Test 1: Check that the object is a data.frame and has 5 columns
test_that("carrot_fly_infestation is a data.frame with 5 columns", {
  expect_s3_class(carrot_fly_infestation, "data.frame")
  expect_equal(ncol(carrot_fly_infestation), 5)
  expect_equal(length(carrot_fly_infestation), 5)
})

# Test 2: Check the number of rows
test_that("carrot_fly_infestation has 96 rows", {
  expect_equal(nrow(carrot_fly_infestation), 96)
})

# Test 3: Validate column names
test_that("carrot_fly_infestation has correct column names", {
  expect_named(
    carrot_fly_infestation,
    c("trt", "gen", "block", "n", "y")
  )
})

# Test 4: Check data types
test_that("carrot_fly_infestation has correct data types", {
  expect_s3_class(carrot_fly_infestation$trt, "factor")
  expect_equal(nlevels(carrot_fly_infestation$trt), 2)
  expect_s3_class(carrot_fly_infestation$gen, "factor")
  expect_equal(nlevels(carrot_fly_infestation$gen), 16)
  expect_s3_class(carrot_fly_infestation$block, "factor")
  expect_equal(nlevels(carrot_fly_infestation$block), 3)
  expect_type(carrot_fly_infestation$n, "integer")
  expect_type(carrot_fly_infestation$y, "integer")
})
