# agridatasets - A Comprehensive Collection of Agricultural and Agronomic Datasets
# Version 0.1.1
# Copyright (C) 2026 Renzo Caceres Rossi
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

#  eelworm_fumigation

library(testthat)

# Test 1: Check that the object is a data.frame and has 10 columns
test_that("eelworm_fumigation is a data.frame with 10 columns", {
  expect_s3_class(eelworm_fumigation, "data.frame")
  expect_equal(ncol(eelworm_fumigation), 10)
  expect_equal(length(eelworm_fumigation), 10)
})

# Test 2: Check the number of rows
test_that("eelworm_fumigation has 48 rows", {
  expect_equal(nrow(eelworm_fumigation), 48)
})

# Test 3: Validate column names
test_that("eelworm_fumigation has correct column names", {
  expect_named(
    eelworm_fumigation,
    c("block", "row", "col", "fumigant", "dose", "initial", "final",
      "grain", "straw", "weeds")
  )
})

# Test 4: Check data types
test_that("eelworm_fumigation has correct data types", {
  expect_s3_class(eelworm_fumigation$block, "factor")
  expect_equal(nlevels(eelworm_fumigation$block), 4)
  expect_type(eelworm_fumigation$row, "integer")
  expect_type(eelworm_fumigation$col, "integer")
  expect_s3_class(eelworm_fumigation$fumigant, "factor")
  expect_equal(nlevels(eelworm_fumigation$fumigant), 5)
  expect_type(eelworm_fumigation$dose, "integer")
  expect_type(eelworm_fumigation$initial, "integer")
  expect_type(eelworm_fumigation$final, "integer")
  expect_type(eelworm_fumigation$grain, "double")
  expect_type(eelworm_fumigation$straw, "double")
  expect_type(eelworm_fumigation$weeds, "double")
})
