# agridatasets - A Comprehensive Collection of Agricultural and Agronomic Datasets
# Version 0.1.1
# Copyright (C) 2026 Renzo Caceres Rossi
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

# egg_weight_daily

library(testthat)

# Test 1: Check that the object is a data.frame and has 2 columns
test_that("egg_weight_daily is a data.frame with 2 columns", {
  expect_s3_class(egg_weight_daily, "data.frame")
  expect_equal(ncol(egg_weight_daily), 2)
  expect_equal(length(egg_weight_daily), 2)
})

# Test 2: Check the number of rows
test_that("egg_weight_daily has 240 rows", {
  expect_equal(nrow(egg_weight_daily), 240)
})

# Test 3: Validate column names
test_that("egg_weight_daily has correct column names", {
  expect_named(
    egg_weight_daily,
    c("day", "weight")
  )
})

# Test 4: Check data types
test_that("egg_weight_daily has correct data types", {
  expect_type(egg_weight_daily$day, "integer")
  expect_type(egg_weight_daily$weight, "integer")
})
