# agridatasets - A Comprehensive Collection of Agricultural and Agronomic Datasets
# Version 0.1.1
# Copyright (C) 2026 Renzo Caceres Rossi
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

# potato_scab_sulfur

library(testthat)

# Test 1: Check that the object is a data.frame and has 4 columns
test_that("potato_scab_sulfur is a data.frame with 4 columns", {
  expect_s3_class(potato_scab_sulfur, "data.frame")
  expect_equal(ncol(potato_scab_sulfur), 4)
  expect_equal(length(potato_scab_sulfur), 4)
})

# Test 2: Check the number of rows
test_that("potato_scab_sulfur has 32 rows", {
  expect_equal(nrow(potato_scab_sulfur), 32)
})

# Test 3: Validate column names
test_that("potato_scab_sulfur has correct column names", {
  expect_named(
    potato_scab_sulfur,
    c("inf", "trt", "row", "col")
  )
})

# Test 4: Check data types
test_that("potato_scab_sulfur has correct data types", {
  expect_type(potato_scab_sulfur$inf, "integer")
  expect_s3_class(potato_scab_sulfur$trt, "factor")
  expect_equal(nlevels(potato_scab_sulfur$trt), 7)
  expect_type(potato_scab_sulfur$row, "integer")
  expect_type(potato_scab_sulfur$col, "integer")
})
