# agridatasets - A Comprehensive Collection of Agricultural and Agronomic Datasets
# Version 0.1.1
# Copyright (C) 2026 Renzo Caceres Rossi
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

# fish_feeding

library(testthat)

# Test 1: Check that the object is a data.frame and has 6 columns
test_that("fish_feeding is a data.frame with 6 columns", {
  expect_s3_class(fish_feeding, "data.frame")
  expect_equal(ncol(fish_feeding), 6)
  expect_equal(length(fish_feeding), 6)
})

# Test 2: Check the number of rows
test_that("fish_feeding has 33 rows", {
  expect_equal(nrow(fish_feeding), 33)
})

# Test 3: Validate column names
test_that("fish_feeding has correct column names", {
  expect_named(
    fish_feeding,
    c("Species", "MaxWt", "Temp", "AR", "Food", "FoodCon")
  )
})

# Test 4: Check data types
test_that("fish_feeding has correct data types", {
  expect_s3_class(fish_feeding$Species, "factor")
  expect_equal(nlevels(fish_feeding$Species), 33)
  expect_type(fish_feeding$MaxWt, "integer")
  expect_type(fish_feeding$Temp, "integer")
  expect_type(fish_feeding$AR, "double")
  expect_s3_class(fish_feeding$Food, "factor")
  expect_equal(nlevels(fish_feeding$Food), 2)
  expect_type(fish_feeding$FoodCon, "double")
})
