# agridatasets - A Comprehensive Collection of Agricultural and Agronomic Datasets
# Version 0.1.1
# Copyright (C) 2026 Renzo Caceres Rossi
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

# nitrofen_toxicity

library(testthat)

# Test 1: Check that the object is a data.frame and has 5 columns
test_that("nitrofen_toxicity is a data.frame with 5 columns", {
  expect_s3_class(nitrofen_toxicity, "data.frame")
  expect_equal(ncol(nitrofen_toxicity), 5)
  expect_equal(length(nitrofen_toxicity), 5)
})

# Test 2: Check the number of rows
test_that("nitrofen_toxicity has 50 rows", {
  expect_equal(nrow(nitrofen_toxicity), 50)
})

# Test 3: Validate column names
test_that("nitrofen_toxicity has correct column names", {
  expect_named(
    nitrofen_toxicity,
    c("conc", "brood1", "brood2", "brood3", "total")
  )
})

# Test 4: Check data types
test_that("nitrofen_toxicity has correct data types", {
  expect_type(nitrofen_toxicity$conc, "double")
  expect_type(nitrofen_toxicity$brood1, "double")
  expect_type(nitrofen_toxicity$brood2, "double")
  expect_type(nitrofen_toxicity$brood3, "double")
  expect_type(nitrofen_toxicity$total, "double")
})
