% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/agridatasets-package.R
\docType{package}
\name{agridatasets}
\alias{agridatasets}
\alias{agridatasets-package}
\title{agridatasets: A Comprehensive Collection of Agricultural and Agronomic Datasets}
\description{
{
This package provides a diverse collection of datasets focused on agriculture, agronomy, animal science, and related fields. The package includes experimental, observational, and field-trial data on crops such as rice, wheat, corn, soybean, cotton, coffee, avocado, and orange, as well as forestry species including bamboo, eucalyptus, and timber.
}
}
\details{
agridatasets: A Comprehensive Collection of Agricultural and Agronomic Datasets

\if{html}{\figure{logo.png}{options: style='float: right' alt='logo' width='120'}}

A Comprehensive Collection of Agricultural and Agronomic Datasets.
}
\seealso{
{
Useful links:
\itemize{
  \item \url{https://github.com/lightbluetitan/agridatasets}
}
}
}
\author{
{
\strong{Maintainer}: Renzo Caceres Rossi \email{arenzocaceresrossi@gmail.com}
}
}
