% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data-documentation.R
\name{nitrofen_toxicity}
\alias{nitrofen_toxicity}
\title{Toxicity of Nitrofen in Aquatic Systems}
\format{
A data frame with 50 observations and 5 variables:
\describe{
  \item{conc}{Numeric vector indicating the nitrofen concentration}
  \item{brood1}{Numeric vector indicating the number of offspring in brood 1}
  \item{brood2}{Numeric vector indicating the number of offspring in brood 2}
  \item{brood3}{Numeric vector indicating the number of offspring in brood 3}
  \item{total}{Numeric vector indicating the total number of offspring}
}
}
\source{
Data taken from the boot package version 1.3-32
}
\usage{
data(nitrofen_toxicity)
}
\description{
This dataset, nitrofen_toxicity, is a data frame containing data from an
experiment to measure the reproductive toxicity of nitrofen on a species
of zooplankton (Ceriodaphnia dubia). Fifty animals were randomized into
batches of ten and each batch was put in a solution with a measured
concentration of nitrofen. It includes information on nitrofen
concentration and brood sizes across three broods along with the total.
}
\details{
The dataset name has been kept as 'nitrofen_toxicity' to avoid confusion
with other datasets in the R ecosystem. This naming convention helps
distinguish this dataset as part of the agridatasets package and assists
users in identifying its specific characteristics.
}
