% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/view_datasets_agridatasets.R
\name{view_datasets_agridatasets}
\alias{view_datasets_agridatasets}
\title{View Available Datasets in agridatasets}
\usage{
view_datasets_agridatasets()
}
\value{
A character vector with the names of the available datasets.
        If no datasets are found, it returns an empty character vector.
}
\description{
This function lists all datasets available in the 'agridatasets' package.
If the 'agridatasets' package is not loaded, it stops and shows an error message.
If no datasets are available, it returns a message and an empty vector.
}
\examples{
if (requireNamespace("agridatasets", quietly = TRUE)) {
  library(agridatasets)
  view_datasets_agridatasets()
}
}
